@@ -17,14 +17,14 @@
 Common classes that provide access to vSphere services.
 """
 
+import http.client as httplib
+import io
 import logging
 
 import netaddr
 from oslo_utils import timeutils
 from oslo_utils import uuidutils
 import requests
-import six
-import six.moves.http_client as httplib
 import suds
 from suds import cache
 from suds import client
@@ -95,7 +95,7 @@ class ServiceMessagePlugin(plugin.MessagePlugin):
         context.envelope.walk(self.add_attribute_for_value)
 
 
-class Response(six.BytesIO):
+class Response(io.BytesIO):
     """Response with an input stream as source."""
 
     def __init__(self, stream, status=200, headers=None):
@@ -103,7 +103,7 @@ class Response(six.BytesIO):
         self.headers = headers or {}
         self.reason = requests.status_codes._codes.get(
             status, [''])[0].upper().replace('_', ' ')
-        six.BytesIO.__init__(self, stream)
+        io.BytesIO.__init__(self, stream)
 
     @property
     def _original_response(self):
@@ -114,7 +114,7 @@ class Response(six.BytesIO):
         return self
 
     def read(self, chunk_size, **kwargs):
-        return six.BytesIO.read(self, chunk_size)
+        return io.BytesIO.read(self, chunk_size)
 
     def info(self):
         return self
@@ -172,7 +172,7 @@ class RequestsTransport(transport.Transport):
 
     def open(self, request):
         resp = self.session.get(request.url, verify=self.verify)
-        return six.BytesIO(resp.content)
+        return io.BytesIO(resp.content)
 
     def send(self, request):
         resp = self.session.post(request.url,
@@ -274,7 +274,8 @@ class Service(object):
                         f_name = f_type.__class__.__name__
                         fault_list.append(f_name)
                         if f_name == exceptions.NO_PERMISSION:
-                            details['object'] = f_type.object.value
+                            details['object'] = \
+                                vim_util.get_moref_value(f_type.object)
                             details['privilegeId'] = f_type.privilegeId
 
         if fault_list:
@@ -349,7 +350,7 @@ class Service(object):
                     op_id = '%s-%s' % (self.op_id_prefix,
                                        uuidutils.generate_uuid())
                     LOG.debug('Invoking %s.%s with opID=%s',
-                              managed_object._type,
+                              vim_util.get_moref_type(managed_object),
                               attr_name,
                               op_id)
                 self._set_soap_headers(op_id)
@@ -413,13 +414,13 @@ class Service(object):
 
                 # Socket errors which need special handling; some of these
                 # might be caused by server API call overload.
-                if (six.text_type(excep).find(ADDRESS_IN_USE_ERROR) != -1 or
-                        six.text_type(excep).find(CONN_ABORT_ERROR)) != -1:
+                if (str(excep).find(ADDRESS_IN_USE_ERROR) != -1 or
+                        str(excep).find(CONN_ABORT_ERROR)) != -1:
                     raise exceptions.VimSessionOverLoadException(
                         _("Socket error in %s.") % attr_name, excep)
                 # Type error which needs special handling; it might be caused
                 # by server API call overload.
-                elif six.text_type(excep).find(RESP_NOT_XML_ERROR) != -1:
+                elif str(excep).find(RESP_NOT_XML_ERROR) != -1:
                     raise exceptions.VimSessionOverLoadException(
                         _("Type error in %s.") % attr_name, excep)
                 else:
@@ -459,5 +460,6 @@ class SudsLogFilter(logging.Filter):
 
         return True
 
+
 # Set log filter to mask/truncate vCenter credentials in suds logs.
 suds.client.log.addFilter(SudsLogFilter())
